@@ -1,5 +1,5 @@
 package Anki::Import ;
-$Anki::Import::VERSION = '0.013';
+$Anki::Import::VERSION = '0.014';
 use strict;
 use warnings;
 use Cwd;
@@ -18,11 +18,24 @@ my $ntype      = 'Basic'; # default note type
 my %notes      = ();      # data structure for storing notes
 my @autotags   = ();      # for storing automated tags
 
+set_log_config('anki-import.cfg', __PACKAGE__);
+#set_log_config('test.cfg', __PACKAGE__);
+
 # argument processing
+arg file => (
+  isa => 'Str',
+  required => 1,
+  comment => 'the name of the source file'
+);
 arg parent_dir => (
   isa => 'Str',
   default => cwd,
-  comment => 'optional directory to save output files, default to current directory',
+  comment => 'optional directory to save output files, defaults to current directory',
+);
+opt quiet => (
+  isa => 'Bool',
+  alias => 'q',
+  comment => 'suppress success message at end'
 );
 opt verbose => (
   isa => 'Bool',
@@ -31,17 +44,19 @@ opt verbose => (
 );
 opt vverbose => (
   isa => 'Bool',
-  alias => 'vv',
+  alias => 'V',
   comment => 'verbose information plus debug info'
 );
 
 # start here
 sub anki_import {
-  my $file = shift;
-  logf('No file passed to Anki::Import. Aborting.') if !$file;
-
   my $args = optargs( @_ );
 
+  my $file = $args->{file};
+  if (!$file) {
+    logf('Aborting: No file passed to Anki::Import.');
+  }
+
   # set log level as appropriate
   if ($args->{verbose}) {
     set_log_level('info');
@@ -52,12 +67,12 @@ sub anki_import {
   }
   logi('Log level set');
 
-
   # get and load the source file
   logi('Loading file');
   my $path  = path($file);
+  logd($path);
   if (!path($file)->exists) {
-    logf("Source file named '$file' does not exist.");
+    logf("Aborting: Source file named '$file' does not exist.");
   };
   @lines = $path->lines_utf8;
 
@@ -67,7 +82,15 @@ sub anki_import {
   # do the stuff we came here for
   validate_src_file();
   logd(\%notes);
-  generate_importable_files($args->{parent_dir});
+
+  my $pd = $args->{parent_dir};
+  generate_importable_files($pd);
+
+  unless ($args->{quiet}) {
+    set_log_level('info');
+    logi("Success! Your import files are in the $pd"
+      . '/anki_import_files directory') unless $args->{quiet};
+  }
   # fin
 }
 
@@ -254,12 +277,16 @@ sub process_note {
     $field_out =~ s'(?<!\\)%(.*?)%'"<ul><li>" . join ("</li><li>", (split (/,\s*/, $1))) . "</li><\/ul>"'gme;
     $field_out =~ s/\\%/%/g;
 
+    $field_out =~ s/ $//;
+
     $field_out .= "\t";
     $out .= $field_out;
   }
+  $out =~ s/(<br>)+\t$|\t$//;
+
+  logd($out, 'processed_line');
 
   # clean up extraneous characters at the end of the line
-  $out =~ s/ *\t$|\t$|(<br>)+\t$//;
 
   # handle autotagging TODO: Ugly, needs cleanup
   if (@autotags && !$new_autotags) {
@@ -275,13 +302,11 @@ sub process_note {
       my $discard_autotag = grep { $_ eq $autotag } @note_tags;
       push @new_tags, $autotag if !$discard_autotag;
     }
-    my @fields = split (/\t/, $out);
-    pop @fields if @note_tags;
-    push @fields, join (',', @new_tags);
-    $out = join "\t", @fields;
+    $out .= join (',', @new_tags);
   }
   $new_autotags = 0;
 
+
   # create cloze fields
   my $cloze_count = 1;
   # TODO: should probably handle escaped braces just in case
@@ -307,7 +332,7 @@ Anki::Import - Anki note generation made easy.
 
 =head1 VERSION
 
-version 0.013
+version 0.014
 
 =head1 OVERVIEW
 
